// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef SOLID_VERSION_H
#define SOLID_VERSION_H

#define SOLID_VERSION_STRING "5.116.0"
#define SOLID_VERSION_MAJOR 5
#define SOLID_VERSION_MINOR 116
#define SOLID_VERSION_PATCH 0
#define SOLID_VERSION ((5<<16)|(116<<8)|(0))

#endif
